Supported synthesizers — pyttsx v1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pyttsx v1.0 documentation »

# Supported synthesizers

Version 1.0 of pyttsx includes drivers for the following text-to-speech synthesizers. Only operating systems on which a driver is tested and known to work are listed. The drivers may work on other systems.

- SAPI5 on Windows XP and Windows Vista
- NSSpeechSynthesizer on Mac OS X 10.5 (Leopard) and 10.6 (Snow Leopard)
- espeak on Ubuntu Desktop Edition 8.10 (Intrepid), 9.04 (Jaunty), and 9.10 (Karmic)

The `pyttsx.init()` documentation explains how to select a specific synthesizer by name as well as the default for each platform.

### Navigation

- index
- modules |
- next |
- previous |
- pyttsx v1.0 documentation »